@@ -7,7 +7,7 @@ use Env qw( @PATH );
 use File::Spec;
 
 # ABSTRACT: Find or build GNU Make
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.18'; # VERSION
 
 
 my $in_path;
@@ -28,7 +28,7 @@ sub import
 sub exe
 {
   my($class) = @_;
-  $class->config('gmake_called');
+  $class->runtime_prop->{command};
 }
 
 
@@ -58,7 +58,7 @@ Alien::gmake - Find or build GNU Make
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
